@@ -11,7 +11,7 @@ use Class::Accessor::Lite (
 use Data::Generator::FromDDL::Director;
 use Data::Generator::FromDDL::Util qw(normalize_parser_str);
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 sub generate {
     my ($self, $num, $out_fh, $format, $pretty, $bytes_per_sql) = @_;
@@ -90,7 +90,7 @@ Data::Generator::FromDDL - Dummy data generator from DDL statements
 =head1 DESCRIPTION
 
 Data::Generator::FromDDL is dummy data generator intended to easily prepare dummy records for RDBMS.
-This module takes care of some constraints specific to RDBMS and generates records in the right order.
+This module takes care of some constraints and generates records in the right order.
 
 Supported constraints are
 
@@ -105,6 +105,9 @@ Supported data types are
     - MEDIUMINT
     - SMALLINT
     - TINYINT
+    - FLOAT
+    - DOUBLE
+    - BOOLEAN (BOOL)
     - TIMESTAMP
     - CHAR
     - VARCHAR
@@ -113,8 +116,6 @@ Supported data types are
     - MEDIUMTEXT
     - ENUM
 
-Currently, composite (PRIMARY|UNIQUE|FOREIGN) KEY constraints are not supported.
-
 =head1 METHODS
 
 =over 4
